############################################################
#Replication: Honig When Reporting Undermines Performance  #
#														   #
#             International Organization                   #
############################################################

/*

This is the public version of the replication archive for Honig When Reporting Undermines Performance.

While the article itself employs data from 9 IDOs, one of these IDOs - the EC - precluded onward disclosure of their data a condition for sharing their data.

As such, this archive excludes the EC's data, meaning the code below generates slightly different results to those published in the final paper.

The IO replication team has seen the full data, and replicated the full results to their satisfaction.

More information on the data is available in the online appendix on my website, danhonig.info.

This .do file is otherwise identical to the 'non-public' .do file and .dta to which the IO replication team had access.

This archive also includes a folder of all outputs from running the non-public .do file on the non-public data (that is, the full data including the EC).

This archive opens by transparently converting the full (non-public) data into the public .dta included with this .do file.

***Converting non-public to public data by dropping the EC data


use "Honig When Reporting Undermines Performance NOT PUBLIC Replication Data 2018.dta"

drop if donor=="EC"

save "Honig When Reporting Undermines Performance PUBLIC Replication Data 2018.dta"

drop _all

use "Selection Analysis Final for IO When Reporting Undermines Performance NOT PUBLIC Replication.dta"

drop if donornum==3
*The donor names are encoded in these data; #3 is the EC.

save "Selection Analysis Final for IO When Reporting Undermines Performance PUBLIC Replication.dta"

*/


****The analysis below proceeds with the "PUBLIC" versions of the data, excluding the EC

drop _all
set more off, permanently


cd "/path/to/replication/directory/"

use "Honig When Reporting Undermines Performance PUBLIC Replication Data 2018.dta"

*/

***Cleaning and Preparation

*dropping projects without results data

drop if six_overall==.


**Setting the panel
encode donor, generate(donornum)
xtset donornum

*Renaming autonomy index to clearly indicate source (Paris Declaration survey vs. my alternative survey)

rename autonomyindex_PD inst_PD_auton_avg_5vars

**Generating necessary interaction between autonomy and results
gen PD5xsfi=sfi_end*inst_PD_auton_avg_5vars

*Creating Z-scores

sort donornum
by donornum: egen donormean=mean(rating_overall)
by donornum: egen donorsd=sd(rating_overall)
gen z_overall=(rating_overall-donormean)/donorsd



***Incorporating survey (that is, my alternate, field survey, measure) of autonomy
generate survey_auton=3 if donor=="EC"
replace survey_auton=5 if donor=="GFATM"
replace survey_auton=3.65 if donor=="WB"
replace survey_auton=4.67 if donor=="JICA"
replace survey_auton=4.33 if donor=="GiZ"
replace survey_auton=4 if donor=="KfW"
replace survey_auton=6 if donor=="IFAD"
replace survey_auton=4.71 if donor=="DFID"


gen surveyautonXsfi=sfi_end*survey_auton
label var survey_auton "Autonomy (Survey)"
label var surveyautonXsfi "SFI*Auton (Survey)"

**Creating dummy vars
tab donor,gen(donordum)
tabulate country_code_COW, gen(countrydum)
rename crs_purpose_code crs_purpose_code_5
rename crs_purpose_sector crs_purpose_sector_3

tab crs_purpose_code_5,gen(crs5dum)
tab crs_purpose_sector_3,gen(crs3dum)
encode (country_code_COW), gen (recipnum)

****


***DROPPING IF SFI missing 

drop if sfi_end==.

*Generating variable labels
label var sfi_end "State Fragility Index (SFI)"
label var PD5xsfi "Autonomy*SFI"
label var z_overall "Project Success (Z-score)"
label var inst_PD_auton_avg_5vars "IDO Autonomy (from Paris Declaration monitoring survey)"
label var sfi_end "Environmental Unpredictability (State Fragility Index)"
label var project_size_USD "Project Size (USD Millions)"
label var six_overall "Overall Project Success (6 pt scale)"

**IO Table 1: Summary Stats
sum six_overall  sfi_end project_size_USD inst_PD_auton_avg_5vars 
*cd "$dataroot/Outreg tables"
sutex2 six_overall  sfi_end project_size_USD inst_PD_auton_avg_5vars, min varlabels


***Table 2 of IO R2 (Main Results)


*Clustered on Recipients
eststo clear
eststo: reg six_overall  sfi_end  PD5xsfi i.donornum, vce (cluster country_code_COW)
eststo:  reg six_overall  sfi_end PD5xsfi project_size_USD i.donornum, vce (cluster country_code_COW)
eststo:  reg six_overall  sfi_end PD5xsfi countrydum1-countrydum178 i.donornum,  vce (cluster country_code_COW)
eststo:  reg six_overall  sfi_end PD5xsfi  project_size_USD countrydum1-countrydum178 i.donornum,  vce (cluster country_code_COW)
eststo:  reg six_overall  sfi_end PD5xsfi  i.crs_purpose_code_5 i.donornum, vce (cluster country_code_COW)
eststo:  reg six_overall  sfi_end PD5xsfi  project_size_USD i.crs_purpose_code_5 i.donornum,  vce (cluster country_code_COW)
eststo:  reg six_overall  sfi_end PD5xsfi  countrydum1-countrydum178 i.crs_purpose_code_5 i.donornum, vce (cluster country_code_COW)
esttab using maintableIOR2RecipientCluster.tex, se label star(* 0.10 ** 0.05 *** 0.01) r2 obslast replace booktabs drop (country*)
*.tex output modified for aesthetic purposes (e.g. adding fixed effects "Y/N" flags); true of all tables in final paper

***For IO Figure 2

reg six_overall  sfi_end  c.sfi_end#c.inst_PD_auton_avg_5vars i.donornum, vce (cluster country_code_COW)
margins, at(sfi_end=(2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22) inst_PD_auton_avg_5vars=(0.56 0.80)) 
marginsplot, scheme (s1mono)

*Modified in Graph Editor to Final Version

***IO Table 3: Expanded Fixed Effects

*Generating 'bins' for year periods

gen fiveyrbin=1 if completionyear>1993 & completionyear<1999
replace fiveyrbin=2 if completionyear>1998 & completionyear<2004
replace fiveyrbin=3 if completionyear>2003 & completionyear<2008
replace fiveyrbin=4 if completionyear>2007 & completionyear<2013
replace fiveyrbin=5 if completionyear>2012

sort donor fiveyrbin


eststo clear
eststo: reg six_overall sfi_end PD5xsfi i.completionyear i.donornum, vce(cluster country_code_COW)
eststo: reg six_overall sfi_end PD5xsfi i.completionyear completionyear#donornum i.donornum, vce(cluster country_code_COW)
eststo:reg six_overall sfi_end PD5xsfi i.fiveyrbin i.recipnum fiveyrbin#recipnum i.donornum, vce(cluster country_code_COW)
eststo: reg six_overall sfi_end PD5xsfi i.fiveyrbin i.recipnum fiveyrbin#donornum fiveyrbin#recipnum i.donornum, vce(cluster country_code_COW)

esttab using tableExpandedTimeFEswithRecipientSEs.tex, se label star(* 0.10 ** 0.05 *** 0.01) r2 obslast replace booktabs


*** IO Table 4: Controlling for Evaluation Type

tab evaluator_external, gen(evalindependentdum)
label var evalindependentdum1 "Internal Eval"
label var evalindependentdum2 "External Eval"
label var evalindependentdum3 "Independent Eval Office"

gen evalinter1=evalindependentdum1*sfi_end
gen evalinter3=evalindependentdum3*sfi_end
gen PD5xInternalEval=inst_PD_auton_avg_5vars*evalindependentdum1
gen PD5xIndependentEval=inst_PD_auton_avg_5vars*evalindependentdum3
gen PD5xInternalEvalxSFI=PD5xInternalEval*sfi_end
gen PD5xIndependentEvalxSFI=PD5xIndependentEval*sfi_end

eststo clear
eststo: reg six_overall sfi_end  PD5xsfi PD5xInternalEval PD5xIndependentEval evalindependentdum1 evalindependentdum3 i.donornum, vce(cluster country_code_COW)
eststo: reg z_overall sfi_end inst_PD_auton_avg_5vars PD5xsfi PD5xInternalEval PD5xIndependentEval evalindependentdum1 evalindependentdum3 i.donornum, vce(cluster country_code_COW)
eststo: reg six_overall sfi_end PD5xsfi PD5xInternalEval PD5xIndependentEval evalindependentdum1 evalindependentdum3 countrydum1-countrydum178 i.donornum, vce(cluster country_code_COW)
eststo: reg z_overall sfi_end inst_PD_auton_avg_5vars PD5xsfi PD5xInternalEval PD5xIndependentEval evalindependentdum1 evalindependentdum3 countrydum1-countrydum178 i.donornum, vce(cluster country_code_COW)
esttab using evalindependentwithrecipSE.tex, se label star(* 0.10 ** 0.05 *** 0.01) r2 booktabs obslast replace


***TABLE 5:  Selection Analysis

/*
This analysis was conducted on a remote computing environment (RCE); generating of the parallel dataset cannot be done without substantial processing time, and is offset here. 

**Transforming for selection analysis: Generating the parallel dataset on project count by IDO by country by sector

drop if crs_purpose_sector_3==.
collapse (count) six_overall, by (completionyear country_code_COW crs_purpose_sector_3 donor)
encode (country_code_COW), gen (recipnum)
encode (donor), gen (donornum)

levelsof completionyear, local(lyear)
levelsof recipnum, local(lcon)
levelsof donornum, local(ldon)
levelsof crs_purpose_sector_3, local(lsec)

qui foreach ly of local lyear { 
foreach lc of local lcon {
	foreach ld of local ldon {
		foreach ls of local lsec {
			count if recipnum==`lc' & donornum ==`ld' & crs_purpose_sector_3==`ls' & completionyear==`ly'
			if "`r(N)'"=="0" {
				set obs `=_N+1'
				replace completionyear=`ly' if _n==_N
				replace recipnum=`lc' if _n==_N
				replace donornum=`ld' if _n==_N
				replace crs_purpose_sector_3=`ls' if _n==_N 
			} 
		} 
	} 
}
}

}

**Could be done on normal computer but already present in data transferred from RCE
sort completionyear recipnum crs_purpose_sector_3 donornum 
rename six_overall obs
replace obs=0 if obs==.
gen auton=.

drop country_code_COW
decode recipnum, gen (country_code_COW)
merge m:1 country_code_COW completionyear using "/Users/danhonig/Dropbox/Dissertation/Stata/Recipient country covariates/recipient Covars long 4 merge.dta"
drop if _merge==1
drop if _merge==2

**Adding autonomy score by donor
gen auton=.
replace auton=.669080436 if donornum==1
replace auton=.798823953 if donornum==2
replace auton=.558577597 if donornum==3
replace auton=.593850553 if donornum==4
replace auton=.666281819 if donornum==5
replace auton=.681465507 if donornum==6
replace auton=.667425275 if donornum==7
replace auton=.666281819 if donornum==8
replace auton=.608462632 if donornum==9

keep obs sfi auton donornum recipnum crs_purpose_sector_3 completionyear


This creates the data loaded immediately below, used to generate table 5 using the code below.
*/

drop _all

use "Selection Analysis Final for IO When Reporting Undermines Performance PUBLIC Replication.dta"


gen autonXsfi=auton*sfi
eststo clear
eststo: reg obs sfi autonXsfi i.donornum, vce (cluster recipnum)
eststo: reg obs sfi autonXsfi i.recipnum i.donornum,  vce (cluster recipnum)
eststo: reg obs sfi autonXsfi i.crs_purpose_sector_3 i.donornum,  vce (cluster recipnum)
eststo: reg obs sfi autonXsfi i.recipnum i.crs_purpose_sector_3 i.donornum,  vce (cluster recipnum)
esttab using Table5Selection.tex, se label star(* 0.05 ** 0.01 *** 0.001) r2 obslast replace booktabs 




